@@ -1,7 +1,7 @@
-class FileRenderer:
+class Template:
     def __init__(self):
         pass
 
-    def render(self, file):
+    def __call__(file):
         with open(file) as f:
-            return f.read()
\ No newline at end of file
+            return f.read()
