@@ -1,10 +1,8 @@
 from webob import Request, Response
-from BBWebFw.FileRenderer import FileRenderer
+from BBWebFw.FileRenderer import Template
 import os, sys, re, datetime
 from gunicorn.app.wsgiapp import run as boot
 
-renderfile = FileRenderer()
-
 class api:
     """
     docstring
@@ -23,9 +21,9 @@ class api:
         response = self.handle_request(request)
         return response(environ, start_response)
 
-    def handle_request(self, request):
+    def handle_request(self, request, mimetype="text/html"):
         #user_agent = request.environ.get('HTTP_USER_AGENT')
-        response = Response()
+        response = Response(content_type=mimetype)
         response.status_code = 200
         response.text = "Blank"
         with open("access-log.txt", "wb") as f:
@@ -81,4 +79,4 @@ class api:
         
         sys.argv = [re.sub(r'(-script\.pyw|\.exe)?$', '', "env/bin/gunicorn"),self.name+':'+ app]
         print(sys.argv)
-        sys.exit(boot())
\ No newline at end of file
+        sys.exit(boot())
